## version_updater.py
Version updater goes through the documents, setup.py and picosdk/version.py and updates each version variable based on _version.py_ in the main folder. 

To run use `python version.py`